NAME
Path::Dispatcher::Rule::Regex - predicate is a regular expression
SYNOPSIS
my $rule = Path::Dispatcher::Rule::Regex->new(
regex => qr{^/comment(s?)/(\d+)$},
block => sub { display_comment(shift->pos(2)) },
);
DESCRIPTION
Rules of this class use a regular expression to match against the path.
ATTRIBUTES
regex
The regular expression to match against the path. It works just as you'd expect!
The capture variables ($1, $2, etc) will be available in the match object as ->pos(1) etc. $`, $&, and $' are not restored.